From: Ole Streicher <olebole@debian.org>
Date: Tue, 13 Dec 2016 09:41:39 +0100
Subject: Mark all known test failures as xfail. These failures have been
 discussed with upstream.

---
 astropy/table/tests/test_info.py                                      | 4 +++-
 astropy/tests/tests/test_socketblocker.py                             | 4 ++--
 astropy/visualization/wcsaxes/tests/test_display_world_coordinates.py | 4 ++++
 astropy/vo/samp/tests/test_standard_profile.py                        | 2 ++
 4 files changed, 11 insertions(+), 3 deletions(-)

diff --git a/astropy/table/tests/test_info.py b/astropy/table/tests/test_info.py
index 2bbcc7a..50fbdb4 100644
--- a/astropy/table/tests/test_info.py
+++ b/astropy/table/tests/test_info.py
@@ -8,6 +8,7 @@ from collections import OrderedDict
 
 import numpy as np
 
+from ...tests.helper import pytest
 from ...extern import six
 from ...extern.six.moves import cStringIO as StringIO
 from ... import units as u
@@ -229,7 +230,8 @@ def test_class_attribute():
         t.info(out=out)
         assert out.getvalue().splitlines() == exp
 
-
+# see https://github.com/astropy/astropy/issues/4336
+@pytest.mark.xfail()
 def test_ignore_warnings():
     t = table.Table([[np.nan, np.nan]])
     with warnings.catch_warnings(record=True) as warns:
diff --git a/astropy/tests/tests/test_socketblocker.py b/astropy/tests/tests/test_socketblocker.py
index c362fa5..783defe 100644
--- a/astropy/tests/tests/test_socketblocker.py
+++ b/astropy/tests/tests/test_socketblocker.py
@@ -66,8 +66,8 @@ PY3_4 = sys.version_info[:2] >= (3, 4)
 def _square(x):
     return x ** 2
 
-
-@pytest.mark.skipif('not PY3_4 or sys.platform == "win32" or sys.platform.startswith("gnu0")')
+# see https://github.com/astropy/astropy/issues/4193
+@pytest.mark.skipif(True, reason="Blocks on Debian CI test")
 def test_multiprocessing_forkserver():
     """
     Test that using multiprocessing with forkserver works.  Perhaps
diff --git a/astropy/visualization/wcsaxes/tests/test_display_world_coordinates.py b/astropy/visualization/wcsaxes/tests/test_display_world_coordinates.py
index 53436dd..4c710e7 100644
--- a/astropy/visualization/wcsaxes/tests/test_display_world_coordinates.py
+++ b/astropy/visualization/wcsaxes/tests/test_display_world_coordinates.py
@@ -3,6 +3,8 @@ from ..core import WCSAxes
 import matplotlib.pyplot as plt
 from matplotlib.backend_bases import KeyEvent
 
+import pytest
+
 from ....wcs import WCS
 from ....extern import six
 from ....coordinates import FK5
@@ -93,6 +95,8 @@ class TestDisplayWorldCoordinate(BaseImageTests):
 
         assert string_world5 == six.u('267.652 -28\xb046\'23" (world, overlay 3)')
 
+    # See https://github.com/astropy/astropy/issues/5601
+    @pytest.mark.xfail()
     def test_cube_coords(self, tmpdir):
         wcs = WCS(self.cube_header)
 
diff --git a/astropy/vo/samp/tests/test_standard_profile.py b/astropy/vo/samp/tests/test_standard_profile.py
index 325ac96..ac25e55 100644
--- a/astropy/vo/samp/tests/test_standard_profile.py
+++ b/astropy/vo/samp/tests/test_standard_profile.py
@@ -62,6 +62,8 @@ class TestStandardProfile(object):
 
         self.hub.stop()
 
+    # see https://github.com/astropy/astropy/issues/5460
+    @pytest.mark.skipif(True, reason="Setup fails due to SSL problems")
     def test_main(self):
 
         self.client1_id = self.client1.get_public_id()
